Index: include/ports/SkFontMgr.h |
diff --git a/include/ports/SkFontMgr.h b/include/ports/SkFontMgr.h |
index 181fe9f6aa93dce9ef833ec38e7ded346ec25cd3..8c61e8fa783f95e031f2a5bda25df065588bcd5c 100644 |
--- a/include/ports/SkFontMgr.h |
+++ b/include/ports/SkFontMgr.h |
@@ -64,14 +64,15 @@ public: |
/** |
* Use the system fallback to find a typeface for the given character. |
* Note that bpc47 is a combination of ISO 639, 15924, and 3166-1 codes, |
* so it is fine to just pass a ISO 639 here. |
* |
* Will return NULL if no family can be found for the character |
* in the system fallback. |
*/ |
SkTypeface* matchFamilyStyleCharacter(const char familyName[], const SkFontStyle&, |
- const char bpc47[], uint32_t character) const; |
+ const char** bcp47, size_t bcpLength, |
reed1
2014/10/21 19:03:42
nit: skia uses "int count" when enumerating an arr
djsollen
2014/10/21 19:41:13
Done.
|
+ SkUnichar character) const; |
SkTypeface* matchFaceStyle(const SkTypeface*, const SkFontStyle&) const; |
@@ -118,7 +119,8 @@ protected: |
const SkFontStyle&) const = 0; |
// TODO: pure virtual, implement on all impls. |
virtual SkTypeface* onMatchFamilyStyleCharacter(const char familyName[], const SkFontStyle&, |
- const char bpc47[], uint32_t character) const |
+ const char** bcp47, size_t bcpLength, |
+ SkUnichar character) const |
{ return NULL; } |
virtual SkTypeface* onMatchFaceStyle(const SkTypeface*, |
const SkFontStyle&) const = 0; |
@@ -64,14 +64,15 @@ public: |
/** |
* Use the system fallback to find a typeface for the given character. |
- * Note that bpc47 is a combination of ISO 639, 15924, and 3166-1 codes, |
+ * Note that bcp47 is a combination of ISO 639, 15924, and 3166-1 codes, |
* so it is fine to just pass a ISO 639 here. |
* |